==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d4/dcb/news__gui_8cpp.js <==
var news__gui_8cpp =
[
    [ "NewsWindow", "d7/d32/structNewsWindow.html", "d7/d32/structNewsWindow" ],
    [ "MessageHistoryWindow", "dd/d60/structMessageHistoryWindow.html", "dd/d60/structMessageHistoryWindow" ],
    [ "AddNewsItem", "d4/dcb/news__gui_8cpp.html#a3c69052fc13233aa8dc20eab45085cec", null ],
    [ "assert_compile", "d4/dcb/news__gui_8cpp.html#a7d7a4a513b73324a7ef6cd519506d3ef", null ],
    [ "ChangeVehicleNews", "d4/dcb/news__gui_8cpp.html#a858330365a0e288a76f22d591b621e91", null ],
    [ "CmdCustomNewsItem", "d4/dcb/news__gui_8cpp.html#a15523eca8bb1fcf7396ff71e0cd0a2cd", null ],
    [ "DeleteIndustryNews", "d4/dcb/news__gui_8cpp.html#a515bc9a73f6b974e1af2442cf2ef2fcb", null ],
    [ "DeleteInvalidEngineNews", "d4/dcb/news__gui_8cpp.html#a6c9a80258b8b1c4a9ebe28289242f7aa", null ],
    [ "DeleteNewsItem", "d4/dcb/news__gui_8cpp.html#af0d1cb09d02228db586c11a54b041450", null ],
    [ "DeleteStationNews", "d4/dcb/news__gui_8cpp.html#a54c55273d67c6c6266b2458e0bcdff01", null ],
    [ "DeleteVehicleNews", "d4/dcb/news__gui_8cpp.html#a1e25d0b7243c70ca1807db5de0eed78b", null ],
    [ "DrawNewsString", "d4/dcb/news__gui_8cpp.html#a0909675a116e7310f0c4755b87ff87f5", null ],
    [ "GetNewsWindowLayout", "d4/dcb/news__gui_8cpp.html#aca29ae73895da6b64dbb72fd6307d6a4", null ],
    [ "GetReferenceTile", "d4/dcb/news__gui_8cpp.html#a863e77bf181c49aca5ff8906ebbb3711", null ],
    [ "InitNewsItemStructs", "d4/dcb/news__gui_8cpp.html#aa0831f5d96c87bb7773260cc4e467e88", null ],
    [ "MoveToNextItem", "d4/dcb/news__gui_8cpp.html#a849b1f4307e9f7bba9bb29f7707411ee", null ],
    [ "NewsLoop", "d4/dcb/news__gui_8cpp.html#a71d5646e7b035600ae82417f6a6f26c0", null ],
    [ "ReadyForNextItem", "d4/dcb/news__gui_8cpp.html#ab65fcc1544761333368e8163b059f93d", null ],
    [ "RemoveOldNewsItems", "d4/dcb/news__gui_8cpp.html#ae806b8f527b1d8e0cd54a0e31b914a0e", null ],
    [ "ShowLastNewsMessage", "d4/dcb/news__gui_8cpp.html#a5ae453afd3a5f5f30c4fe1bdc1b496c8", null ],
    [ "ShowMessageHistory", "d4/dcb/news__gui_8cpp.html#a8351e0f7805ed9c0f9ec71733db63dc8", null ],
    [ "ShowNewsMessage", "d4/dcb/news__gui_8cpp.html#abc36d5656909921a3aeb276356fdaa00", null ],
    [ "ShowNewspaper", "d4/dcb/news__gui_8cpp.html#a1e70392917f11995e432d79534e59ad1", null ],
    [ "ShowTicker", "d4/dcb/news__gui_8cpp.html#abcb6658a7e966e33ab45554769bc89c8", null ],
    [ "_company_news_desc", "d4/dcb/news__gui_8cpp.html#ae9723cd3add98c10a8e6564f523099c0", null ],
    [ "_current_news", "d4/dcb/news__gui_8cpp.html#ac970834a0dbbe071c364041c20f5f6b8", null ],
    [ "_forced_news", "d4/dcb/news__gui_8cpp.html#a1dcfd4183c31fb9f669bc5dfc3023be8", null ],
    [ "_latest_news", "d4/dcb/news__gui_8cpp.html#a88f4c68c4fb7ff7a586dc947e9badc73", null ],
    [ "_message_history_desc", "d4/dcb/news__gui_8cpp.html#afb0fb0429496f7cfe7ebc78c8f28fddd", null ],
    [ "_nested_company_news_widgets", "d4/dcb/news__gui_8cpp.html#a676c6cee7d86629d97d8d3a97ed90f5d", null ],
    [ "_nested_message_history", "d4/dcb/news__gui_8cpp.html#afaa9cd1b22e273c5cd8790c815b25a21", null ],
    [ "_nested_normal_news_widgets", "d4/dcb/news__gui_8cpp.html#a60a313999261da6ecd3649a4cb311826", null ],
    [ "_nested_small_news_widgets", "d4/dcb/news__gui_8cpp.html#a8ed4e6b9af008646dedcbb9697ddfa25", null ],
    [ "_nested_thin_news_widgets", "d4/dcb/news__gui_8cpp.html#a3f6a1edc24df051b5f7a592976c903b5", null ],
    [ "_nested_vehicle_news_widgets", "d4/dcb/news__gui_8cpp.html#a5ea2f4784a922a17ea91dba26ef1c13e", null ],
    [ "_news_type_data", "d4/dcb/news__gui_8cpp.html#a2d92fe38509cc08580e9f87204aec0c0", null ],
    [ "_news_window_layout", "d4/dcb/news__gui_8cpp.html#aea0da0f3ac2b85cc68604cf4f26d0e94", null ],
    [ "_normal_news_desc", "d4/dcb/news__gui_8cpp.html#a2be44c1ea52518b82de5107fd96fe048", null ],
    [ "_oldest_news", "d4/dcb/news__gui_8cpp.html#ad8ce3e94c4fa1f442a91bc35d6e85390", null ],
    [ "_small_news_desc", "d4/dcb/news__gui_8cpp.html#af1656c0ad3fc4224f8e11a28adf4560c", null ],
    [ "_statusbar_news_item", "d4/dcb/news__gui_8cpp.html#ad2051408b5fa7531c93b9244088a48ad", null ],
    [ "_thin_news_desc", "d4/dcb/news__gui_8cpp.html#a4a7a9633ee32f195b387d58972a9f4dd", null ],
    [ "_total_news", "d4/dcb/news__gui_8cpp.html#aee05dafd640f5e4fc59cb5d9bc1849c8", null ],
    [ "_vehicle_news_desc", "d4/dcb/news__gui_8cpp.html#a60fcdae9a81ae485ce7d0d18f40c2b7d", null ],
    [ "MIN_NEWS_AMOUNT", "d4/dcb/news__gui_8cpp.html#ad8cf69444819038ecad3b1d830ccc295", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d4/dcb/news__gui_8cpp.js <==
var news__gui_8cpp =
[
    [ "NewsWindow", "d7/d32/structNewsWindow.html", "d7/d32/structNewsWindow" ],
    [ "MessageHistoryWindow", "dd/d60/structMessageHistoryWindow.html", "dd/d60/structMessageHistoryWindow" ],
    [ "AddNewsItem", "d4/dcb/news__gui_8cpp.html#a3c69052fc13233aa8dc20eab45085cec", null ],
    [ "ChangeVehicleNews", "d4/dcb/news__gui_8cpp.html#a858330365a0e288a76f22d591b621e91", null ],
    [ "CmdCustomNewsItem", "d4/dcb/news__gui_8cpp.html#a15523eca8bb1fcf7396ff71e0cd0a2cd", null ],
    [ "DeleteIndustryNews", "d4/dcb/news__gui_8cpp.html#a515bc9a73f6b974e1af2442cf2ef2fcb", null ],
    [ "DeleteInvalidEngineNews", "d4/dcb/news__gui_8cpp.html#a6c9a80258b8b1c4a9ebe28289242f7aa", null ],
    [ "DeleteNewsItem", "d4/dcb/news__gui_8cpp.html#af0d1cb09d02228db586c11a54b041450", null ],
    [ "DeleteStationNews", "d4/dcb/news__gui_8cpp.html#a54c55273d67c6c6266b2458e0bcdff01", null ],
    [ "DeleteVehicleNews", "d4/dcb/news__gui_8cpp.html#a1e25d0b7243c70ca1807db5de0eed78b", null ],
    [ "DrawNewsString", "d4/dcb/news__gui_8cpp.html#a0909675a116e7310f0c4755b87ff87f5", null ],
    [ "GetNewsWindowLayout", "d4/dcb/news__gui_8cpp.html#aca29ae73895da6b64dbb72fd6307d6a4", null ],
    [ "GetReferenceTile", "d4/dcb/news__gui_8cpp.html#a863e77bf181c49aca5ff8906ebbb3711", null ],
    [ "HideActiveNewsMessage", "d4/dcb/news__gui_8cpp.html#a7d85d6d3c3e4ffc19fa1085b60f170a9", null ],
    [ "InitNewsItemStructs", "d4/dcb/news__gui_8cpp.html#aa0831f5d96c87bb7773260cc4e467e88", null ],
    [ "MoveToNextNewsItem", "d4/dcb/news__gui_8cpp.html#a1094bdd3510174194299116374996f3b", null ],
    [ "MoveToNextTickerItem", "d4/dcb/news__gui_8cpp.html#aa1ad24fadb6dc674c8d0cdd68b9afa20", null ],
    [ "NewsLoop", "d4/dcb/news__gui_8cpp.html#a71d5646e7b035600ae82417f6a6f26c0", null ],
    [ "ReadyForNextNewsItem", "d4/dcb/news__gui_8cpp.html#a738d96285f7eeddaa87d1620c7fdac13", null ],
    [ "ReadyForNextTickerItem", "d4/dcb/news__gui_8cpp.html#ae98b10c13405ac725c5b950ad61969d4", null ],
    [ "RemoveOldNewsItems", "d4/dcb/news__gui_8cpp.html#ae806b8f527b1d8e0cd54a0e31b914a0e", null ],
    [ "ShowLastNewsMessage", "d4/dcb/news__gui_8cpp.html#a5ae453afd3a5f5f30c4fe1bdc1b496c8", null ],
    [ "ShowMessageHistory", "d4/dcb/news__gui_8cpp.html#a8351e0f7805ed9c0f9ec71733db63dc8", null ],
    [ "ShowNewsMessage", "d4/dcb/news__gui_8cpp.html#abc36d5656909921a3aeb276356fdaa00", null ],
    [ "ShowNewspaper", "d4/dcb/news__gui_8cpp.html#a1e70392917f11995e432d79534e59ad1", null ],
    [ "ShowTicker", "d4/dcb/news__gui_8cpp.html#abcb6658a7e966e33ab45554769bc89c8", null ],
    [ "_company_news_desc", "d4/dcb/news__gui_8cpp.html#a54a970d53428ce232ea048c1abe1c359", null ],
    [ "_current_news", "d4/dcb/news__gui_8cpp.html#ac970834a0dbbe071c364041c20f5f6b8", null ],
    [ "_forced_news", "d4/dcb/news__gui_8cpp.html#a1dcfd4183c31fb9f669bc5dfc3023be8", null ],
    [ "_latest_news", "d4/dcb/news__gui_8cpp.html#a88f4c68c4fb7ff7a586dc947e9badc73", null ],
    [ "_message_history_desc", "d4/dcb/news__gui_8cpp.html#afb0fb0429496f7cfe7ebc78c8f28fddd", null ],
    [ "_nested_company_news_widgets", "d4/dcb/news__gui_8cpp.html#a676c6cee7d86629d97d8d3a97ed90f5d", null ],
    [ "_nested_message_history", "d4/dcb/news__gui_8cpp.html#afaa9cd1b22e273c5cd8790c815b25a21", null ],
    [ "_nested_normal_news_widgets", "d4/dcb/news__gui_8cpp.html#a60a313999261da6ecd3649a4cb311826", null ],
    [ "_nested_small_news_widgets", "d4/dcb/news__gui_8cpp.html#a8ed4e6b9af008646dedcbb9697ddfa25", null ],
    [ "_nested_thin_news_widgets", "d4/dcb/news__gui_8cpp.html#a3f6a1edc24df051b5f7a592976c903b5", null ],
    [ "_nested_vehicle_news_widgets", "d4/dcb/news__gui_8cpp.html#a5ea2f4784a922a17ea91dba26ef1c13e", null ],
    [ "_news_type_data", "d4/dcb/news__gui_8cpp.html#a2d92fe38509cc08580e9f87204aec0c0", null ],
    [ "_news_window_layout", "d4/dcb/news__gui_8cpp.html#aea0da0f3ac2b85cc68604cf4f26d0e94", null ],
    [ "_normal_news_desc", "d4/dcb/news__gui_8cpp.html#a6bcf79ae4358edd58d311fd5d6f92312", null ],
    [ "_oldest_news", "d4/dcb/news__gui_8cpp.html#ad8ce3e94c4fa1f442a91bc35d6e85390", null ],
    [ "_small_news_desc", "d4/dcb/news__gui_8cpp.html#aceda68e63930ea09667080c71bb152c8", null ],
    [ "_statusbar_news_item", "d4/dcb/news__gui_8cpp.html#ad2051408b5fa7531c93b9244088a48ad", null ],
    [ "_thin_news_desc", "d4/dcb/news__gui_8cpp.html#aad894aa5e325daa6d28fade281e9eb18", null ],
    [ "_total_news", "d4/dcb/news__gui_8cpp.html#aee05dafd640f5e4fc59cb5d9bc1849c8", null ],
    [ "_vehicle_news_desc", "d4/dcb/news__gui_8cpp.html#a793a220858f961250962c2255e1846f6", null ],
    [ "MAX_NEWS_AMOUNT", "d4/dcb/news__gui_8cpp.html#a8197382c587ec6996df905ee2b719481", null ],
    [ "MIN_NEWS_AMOUNT", "d4/dcb/news__gui_8cpp.html#ad8cf69444819038ecad3b1d830ccc295", null ]
];
